Credits
=======

Development Leads
-----------------

* Chun Fai Tung <ctung6@gatech.edu>
* Ignacio Taboada <itaboada@gatech.edu>

Contributors
-----------

* Theo Glauch <theo.glauch@icecube.wisc.edu>
* Michael Larson <michael.larson@icecube.wisc.edu>
* Alex Pizzuto <pizzuto@icecube.wisc.edu>
* René Reimann <reimann@icecube.wisc.edu>

